=============
 oslo.vmware
=============

The Oslo VMware library provides support for common VMware operations and APIs.

* License: Apache License, Version 2.0
* Documentation: http://docs.openstack.org/developer/oslo.vmware
* Source: http://git.openstack.org/cgit/openstack/oslo.vmware
* Bugs: http://bugs.launchpad.net/oslo.vmware
